"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const fs_1 = __importDefault(require("fs"));
const manifest_1 = __importDefault(require("./manifest"));
const sharp_1 = __importDefault(require("./sharp"));
const svgJS_1 = __importDefault(require("./svgJS"));
class $CryptoIcons {
    constructor() {
        this.coins = this.load();
    }
    load() {
        return manifest_1.default.map((coin) => ({ ...coin }));
    }
    forEach(prepare, callback, save) {
        this.coins.forEach((coin) => {
            const arg = prepare(coin);
            callback(arg, { ...coin });
            save && save(arg, coin);
        });
    }
    /**
     * Write the manifest file for `coins`
     *
     * @param path A string specifying where you want to save the files to.
     * @param name The name of the file to save (default is manifest.json)
     * @param callback Function that called for each `Coin` then the returned value added to manifest. (default coin)
     * @returns `CryptoIcons`
     */
    saveManifest(path, name = "manifest.json", callback = (coin) => coin) {
        const callbackFn = (coin) => callback({ ...coin });
        const manifest = this.coins.map(callbackFn);
        fs_1.default.mkdirSync(path, { recursive: true });
        fs_1.default.writeFileSync(`${path}/${name}`, JSON.stringify(manifest));
        return this;
    }
    /**
     * Manipulating SVG elements whit SVG.JS library
     *
     * @param callback It gives you a SVG.JS Container and you can manipulate svg whit it
     * @returns `CryptoIcons`
     */
    modifySVG(callback) {
        this.forEach((coin) => svgJS_1.default(coin.svg), callback, (svgElement, coin) => (coin.svg = svgElement.svg()));
        return this;
    }
    /**
     * Process SVG image whit `sharp`
     *
     * @param callback It gives you a Sharp instance and you can process svg whit it
     * @returns `CryptoIcons`
     */
    sharp(callback) {
        this.forEach((coin) => sharp_1.default(coin.svg), callback);
        return this;
    }
    /**
     * Filter the coins that meet the condition specified in a callback function.
     *
     * @param callback Function is a predicate, to test each Coin. Return a value that coerces to true to keep the element, or to false otherwise.
     * @returns `CryptoIcons`
     */
    filter(callback) {
        this.coins = this.coins.filter(callback);
        return this;
    }
    /**
     * Write the svg of each coin in its own file
     *
     * @param path A string specifying where you want to save the files to.
     * @param name The name of the file to save the svg of the Coin (default is `coin.id`.svg)
     * @returns `CryptoIcons`
     */
    saveSVG(path, name) {
        fs_1.default.mkdirSync(path, { recursive: true });
        this.forEach(name || ((coin) => `${coin.id}.svg`), (name, coin) => fs_1.default.writeFileSync(`${path}/${name}`, coin.svg));
        return this;
    }
    /**
     * Reload all coins
     *
     * @returns `CryptoIcons`
     */
    reload() {
        this.coins = this.load();
        return this;
    }
    /**
     * add operations to objects
     *
     * @returns `CryptoIcons`
     */
    operation(operation) {
        operation.visit(this);
        return this;
    }
}
exports.default = $CryptoIcons;
